@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _ANJUTA_UI_H_
 #define _ANJUTA_UI_H_
@@ -32,8 +32,8 @@
  * removed from it and accordingly updates the required UI interfaces.
  * Use the EggMenuMerge object only to do things not doable by AnjutaUI.
  */
-#include <gtk/gtkaccelgroup.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -130,6 +130,55 @@ GtkWidget* anjuta_ui_get_accel_editor (AnjutaUI *ui);
 /* Dump the whole tree in STDOUT. Useful for debugging */
 void anjuta_ui_dump_tree (AnjutaUI *ui);
 
+/* Loading and saving accels */
+void anjuta_ui_load_accels (void);
+
+void anjuta_ui_save_accels (void);
+
+/* Convenience macros to register stock icons */
+#define BEGIN_REGISTER_ICON(plugin) \
+{ \
+	AnjutaUI *ui = anjuta_shell_get_ui ((plugin)->shell, NULL); \
+	GtkIconFactory *icon_factory = anjuta_ui_get_icon_factory (ui); \
+	GtkIconSet *icon_set; \
+	GtkIconSource *	icon_source = gtk_icon_source_new ();
+
+/* Register icon with size 16 and size 24, icon should be the 
+ * filename (without path) striped of the size (16,24) and the *.png
+ * (e.g anjuta-icon-24.png => anjuta-icon)
+ */
+
+#define REGISTER_ICON_FULL(icon, stock_id) \
+	icon_set = gtk_icon_set_new(); \
+	gtk_icon_source_set_filename (icon_source, PACKAGE_PIXMAPS_DIR"/"icon"-16.png"); \
+	gtk_icon_source_set_size (icon_source, 16); \
+	gtk_icon_set_add_source (icon_set, icon_source); \
+	gtk_icon_source_set_filename (icon_source, PACKAGE_PIXMAPS_DIR"/"icon"-24.png"); \
+	gtk_icon_source_set_size (icon_source, 24); \
+	gtk_icon_set_add_source (icon_set, icon_source); \
+	icon_set = gtk_icon_set_new(); \
+	gtk_icon_set_add_source (icon_set, icon_source); \
+	gtk_icon_factory_add (icon_factory, stock_id, icon_set);
+
+/* Register icon for all sizes (will be scaled) 
+ * icon should be the full filename without path (e.g anjuta-icon.png)
+ */
+
+#define REGISTER_ICON(icon, stock_id) \
+	{ \
+	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"icon, NULL); \
+	if (pixbuf) \
+	{ \
+		icon_set = gtk_icon_set_new_from_pixbuf (pixbuf); \
+		gtk_icon_factory_add (icon_factory, stock_id, icon_set); \
+		g_object_unref (pixbuf); \
+	} \
+	}
+
+#define END_REGISTER_ICON \
+	gtk_icon_source_free (icon_source); \
+}
+
 G_END_DECLS
 
 #endif
