@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 /*
  * Most of the code stolen from SciTE and heavily modified.
@@ -47,12 +47,14 @@ AnEditor::AnEditor(PropSetFile* p) {
 	characterSet = 0;
 	language = "java";
 	lexLanguage = SCLEX_CPP;
+	/*
 	indentSize = 8;
 	indentOpening = true;
 	indentClosing = true;
-	indentMaintain = true;
 	statementLookback = 10;
-
+	*/
+	indentMaintain = true;
+	
 	wrapLine = true;
 	isReadOnly = false;
 	fnEditor = 0;
@@ -108,7 +110,7 @@ AnEditor::AnEditor(PropSetFile* p) {
 
 	accelGroup = NULL;
 	calltipShown = false;
-	debugTipOn = false;
+	// debugTipOn = false;
 	
 	fileName[0] = '\0';
 	props = p;
@@ -134,12 +136,12 @@ AnEditor::AnEditor(PropSetFile* p) {
 	/* Set default editor mode */
 	SendEditor(SCI_SETEOLMODE, SC_EOL_LF);
 	
+#if 0
 	// Trap 'TAB' key for automatic indentation.
 	// SendEditor (SCI_ASSIGNCMDKEY, SCK_TAB, SCI_NULL);
 	g_signal_connect (wEditor.GetID(), "key-press-event",
 					  G_CALLBACK (KeyPressEvent), this);
 
-#if 0
 	/* Register images to be used for autocomplete */
 	typedef struct {
 		SVNodeType type;
@@ -380,6 +382,8 @@ void AnEditor::GetRange(guint start, guint end, gchar *text, gboolean styled) {
 		SendEditor (SCI_GETTEXTRANGE, 0, reinterpret_cast<long>(&tr));
 }
 
+#if 0
+
 /**
  * Check if the given line is a preprocessor condition line.
  * @return The kind of preprocessor condition (enum values).
@@ -513,6 +517,8 @@ bool AnEditor::FindMatchingPreprocCondPosition(
 	}
 	return isInside;
 }
+#endif
+
 #ifdef __BORLANDC__
 #pragma warn .aus
 #endif
@@ -601,9 +607,9 @@ void AnEditor::BraceMatch(bool editor) {
 			int indentPosNext = Platform::SendScintilla(win.GetID(), SCI_GETLINEINDENTPOSITION, lineStart + 1, 0);
 			columnAtCaret = Platform::SendScintilla(win.GetID(), SCI_GETCOLUMN, indentPos, 0);
 			int columnAtCaretNext = Platform::SendScintilla(win.GetID(), SCI_GETCOLUMN, indentPosNext, 0);
-			int indentSize = Platform::SendScintilla(win.GetID(), SCI_GETINDENT);
-			if (columnAtCaretNext - indentSize > 1)
-				columnAtCaret = columnAtCaretNext - indentSize;
+			int indentationSize = Platform::SendScintilla(win.GetID(), SCI_GETINDENT);
+			if (columnAtCaretNext - indentationSize > 1)
+				columnAtCaret = columnAtCaretNext - indentationSize;
 			//Platform::DebugPrintf(": %d %d %d\n", lineStart, indentPos, columnAtCaret);
 			if (columnOpposite == 0)	// If the final line of the structure is empty
 				columnOpposite = columnAtCaret;
@@ -720,6 +726,11 @@ long AnEditor::Find (long flags, char* findWhat) {
 
 void AnEditor::BookmarkToggle( int lineno ) {
 	if (lineno == -1)
+		
+		
+		
+		
+		
 		lineno = GetCurrentLineNumber();
 	int state = SendEditor(SCI_MARKERGET, lineno);
 	if ( state & (1 << ANE_MARKER_BOOKMARK))
@@ -746,12 +757,12 @@ void AnEditor::BookmarkPrev() {
 	if (nextLine < 0 || nextLine == lineno) {
 		if(props->GetInt("editor.wrapbookmarks")) {
 			int nrOfLines = SendEditor(SCI_GETLINECOUNT, 0, 1 << ANE_MARKER_BOOKMARK);
-			int nextLine = SendEditor(SCI_MARKERPREVIOUS, nrOfLines, 1 << ANE_MARKER_BOOKMARK);
-			if (nextLine < 0 || nextLine == lineno) {
+			int nextLine1 = SendEditor(SCI_MARKERPREVIOUS, nrOfLines, 1 << ANE_MARKER_BOOKMARK);
+			if (nextLine1 < 0 || nextLine1 == lineno) {
 				gdk_beep(); // how do I beep? -- like this ;-)
 			} else {
-				SendEditor(SCI_ENSUREVISIBLE, nextLine);
-				SendEditor(SCI_GOTOLINE, nextLine);
+				SendEditor(SCI_ENSUREVISIBLE, nextLine1);
+				SendEditor(SCI_GOTOLINE, nextLine1);
 			}
 		}
 	} else {
@@ -765,12 +776,12 @@ void AnEditor::BookmarkNext() {
 	int nextLine = SendEditor(SCI_MARKERNEXT, lineno + 1, 1 << ANE_MARKER_BOOKMARK);
 	if (nextLine < 0 || nextLine == lineno) {
 		if(props->GetInt("editor.wrapbookmarks")) {
-			int nextLine = SendEditor(SCI_MARKERNEXT, 0, 1 << ANE_MARKER_BOOKMARK);
-			if (nextLine < 0 || nextLine == lineno) {
+			int nextLine1 = SendEditor(SCI_MARKERNEXT, 0, 1 << ANE_MARKER_BOOKMARK);
+			if (nextLine1 < 0 || nextLine1 == lineno) {
 				gdk_beep(); // how do I beep? -- like this ;-)
 			} else {				
-				SendEditor(SCI_ENSUREVISIBLE, nextLine);
-				SendEditor(SCI_GOTOLINE, nextLine);
+				SendEditor(SCI_ENSUREVISIBLE, nextLine1);
+				SendEditor(SCI_GOTOLINE, nextLine1);
 			}
 		}
 	} else {
@@ -1211,7 +1222,7 @@ bool AnEditor::StartStreamComment() {
 	return true;
 }
 
-
+#if 0
 SString AnEditor::GetMode(SString language) {
 	SString mode;	
 	if (strcmp(language.c_str(), "cpp") == 0)
@@ -1333,6 +1344,7 @@ bool AnEditor::InsertCustomIndent() {
 	return TRUE;
 }
 	
+#endif
 
 /**
  * Return the length of the given line, not counting the EOL.
@@ -1362,82 +1374,12 @@ void AnEditor::CharAdded(char ch) {
 		int style = SendEditor(SCI_GETSTYLEAT, selStart - 1, 0);
 		if (style != 1) {
 			if (SendEditor(SCI_CALLTIPACTIVE)) {		// calltip is active
-				if (ch == ')') {								// close our calltip
-					
-					braceCount--;
-										
-					if (braceCount < 1) {					// shutdown at all
-						ShutDownCallTip();
-						SendEditor(SCI_CALLTIPCANCEL);
-						return;
-					}
-					
-					ResumeCallTip();
-				} else if (ch == '(') {						// a new calltip is encountered?...
-					SaveCallTip();
-					braceCount++;
-					StartCallTip_new();					
-				} else {
-					// here it is, we continue the calltip
-					//ContinueCallTip();
-					ContinueCallTip_new();
-				}
 			} else if (SendEditor(SCI_AUTOCACTIVE)) {	// word autocompletion
-				if (ch == '(') {
-					braceCount++;
-					//StartCallTip();
-					StartCallTip_new();
-				} else if (ch == ')') {
-					braceCount--;
-				} else if (!wordCharacters.contains(ch)) {
-					SendEditor(SCI_AUTOCCANCEL);
-					if (autocompletion) {
-						g_completion_free (autocompletion);
-						autocompletion = NULL;
-					}
-				} else if (autoCCausedByOnlyOne) {
-					StartAutoCompleteWord(props->GetInt("autocompleteword.automatic"));
-				} else {
-					StartAutoCompleteWord(0);
-				}
 			} else if (HandleXml(ch)) {
 				// Handled in the routine
-			}
-			else {	// we don't have autocompetion nor calltip active
-				if (autocompletion) {
-					g_completion_free (autocompletion);
-					autocompletion = NULL;
-				}
-				if (ch == '(') {
-					braceCount = 1;
-					//StartCallTip();
-					
-					//
-					// check whether we have some left nodes in call_tip_node_queue: this
-					// can happen if we hit the "down key" when calltip is active
-					//
-					
-					if ( g_queue_is_empty( call_tip_node_queue ) != TRUE )
-						ShutDownCallTip();
-					
-					// ok, let's start a new calltip			
-					StartCallTip_new();
-				} else {
-					autoCCausedByOnlyOne = false;
+			} else {	// we don't have autocompetion nor calltip active
 					if (indentMaintain)
 						MaintainIndentation(ch);
-					else if (props->GetInt("indent.automatic"))
-						AutomaticIndentation(ch);
-					if (autoCompleteStartCharacters.contains(ch)) {
-						StartAutoComplete();
-					} else if (props->GetInt("autocompleteword.automatic") &&
-							   !StartAutoCompleteRecordsFields(ch) &&
-							   wordCharacters.contains(ch)) {
-						
-					    StartAutoCompleteWord(props->GetInt("autocompleteword.automatic"));
-					    autoCCausedByOnlyOne = SendEditor(SCI_AUTOCACTIVE);
-					}
-				}
 			}
 		}
 	}
@@ -1645,6 +1587,9 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	
 	case ANE_GETCURRENTWORD:
 		return GetCurrentWord((char*)wParam, (int)lParam);
+		
+	case ANE_GETWORDBEFORECARAT:
+		return GetWordBeforeCarat((char*)wParam, (int)lParam);
 
 	case ANE_SHOWCALLTIP:
 		StartCallTip_new();
@@ -1653,7 +1598,7 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_COMPLETECALLTIP:
 		CompleteCallTip();	
 		break;
-	
+	/*
 	case ANE_COMPLETE:
 		StartAutoComplete();
 		break;
@@ -1661,7 +1606,7 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_COMPLETEWORD:
 		StartAutoCompleteWord(false);
 		break;
-	
+	*/
 	case ANE_TOGGLE_FOLD:
 		FoldToggle();
 		break;
@@ -1855,10 +1800,10 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	
 	case ANE_STREAMCOMMENT:
 		return StartStreamComment();
-	
+	/*
 	case ANE_CUSTOMINDENT:
 		return InsertCustomIndent();
-	
+	*/
 	case ANE_WORDSELECT:
 		WordSelect();
 		break;
@@ -1876,11 +1821,11 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_SETWRAPBOOKMARKS:
 		// Nothing to do.
 		break;
-		
+	/*
 	case ANE_SETAUTOINDENTATION:
 		// Nothing to do.
 		break;
-		
+	*/
 	case ANE_SETUSETABFORINDENT:
 		SendEditor(SCI_SETUSETABS, wParam);
 		break;
@@ -1889,11 +1834,11 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 		indentSize = wParam;
 		SendEditor(SCI_SETINDENT, wParam);
 		break;
-		
+	
 	case ANE_SETINDENTBRACESCHECK:
 		bracesCheck = wParam;
 		break;
-		
+	/*
 	case ANE_SETINDENTOPENING:
 		indentOpening = wParam;
 		break;
@@ -1901,7 +1846,7 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_SETINDENTCLOSING:
 		indentClosing = wParam;
 		break;
-		
+	*/
 	case ANE_SETINDENTMAINTAIN:
 		if (wParam)
 			props->Set ("indent.maintain.*", "1");
@@ -1909,6 +1854,7 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 			props->Set ("indent.opening.*", "0");
 		indentMaintain = wParam;
 		break;
+	
 	case ANE_SETTABINDENTS:
 		SendEditor(SCI_SETTABINDENTS, wParam);
 		break;
@@ -1916,7 +1862,7 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_SETBACKSPACEUNINDENTS:
 		SendEditor(SCI_SETBACKSPACEUNINDENTS, wParam);
 		break;
-		
+	
 	case ANE_SETFOLDSYMBOLS:
 		SetFoldSymbols(reinterpret_cast<char *> (wParam));
 		break;
@@ -2159,9 +2105,11 @@ bool AnEditor::MarginClick(int position, int modifiers) {
 	return true;
 }
 
+#if 0
 gint AnEditor::KeyPressEvent(GtkWidget *, GdkEventKey *event, AnEditor *anedit) {
 	return anedit->KeyPress(event->state, event->keyval);
 }
+#endif
 
 void AnEditor::NotifySignal(GtkWidget *, gint /*wParam*/, gpointer lParam, AnEditor *anedit) {
 	anedit->Notify(reinterpret_cast<SCNotification *>(lParam));
@@ -2190,7 +2138,6 @@ eval_output_arrived_for_aneditor(GList* lines, gpointer data)
 
 	info->editor->EvalOutputArrived(lines, info->textPos, info->expression);
 }
-#endif
 
 void AnEditor::EvalOutputArrived(GList* lines, int textPos,
 								 const string &expression) {
@@ -2227,8 +2174,6 @@ void AnEditor::HandleDwellStart(int mousePos) {
 		return;
 
 	char expr[256];
-//FIXME:
-#if 0
 	if (!debugger_is_active() || !debugger_is_ready())
 	{
 		// Do not show expression tip if it can't be shown.
@@ -2236,7 +2181,6 @@ void AnEditor::HandleDwellStart(int mousePos) {
 		// SendEditorString(SCI_CALLTIPSHOW, mousePos, s.c_str());
 		return;
 	}
-#endif	
 	// If debug tip is already running, return.
 	if (debugTipOn)
 		return;
@@ -2281,16 +2225,15 @@ void AnEditor::HandleDwellStart(int mousePos) {
 	// We don't want static members of classes to clutter up
 	// the displayed tip, however.
 
-//FIXME:
-#if 0
 	ExpressionEvaluationTipInfo *info =
 			new ExpressionEvaluationTipInfo(this, mousePos, expr);
 	debugger_query_evaluate_expr_tip (expr, eval_output_arrived_for_aneditor, info);
 	debugger_query_execute ();
-#endif
 	debugTipOn = true;
 }
+#endif
 
+#if 0
 int AnEditor::KeyPress(unsigned int state, unsigned int keyval){
 
 	unsigned int mask = GDK_SHIFT_MASK | GDK_LOCK_MASK |
@@ -2319,6 +2262,7 @@ int AnEditor::KeyPress(unsigned int state, unsigned int keyval){
 	}
 	return false;
 }
+#endif
 
 void AnEditor::Notify(SCNotification *notification) {
 	switch (notification->nmhdr.code) {
@@ -2390,7 +2334,7 @@ void AnEditor::Notify(SCNotification *notification) {
 			EnsureRangeVisible(notification->position, notification->position + notification->length);
 		}
 		break;
-
+/*
 	case SCN_DWELLSTART:
 		HandleDwellStart(notification->position);
 		break;
@@ -2399,7 +2343,7 @@ void AnEditor::Notify(SCNotification *notification) {
 		EndDebugEval();
 		// SendEditor(SCI_CALLTIPCANCEL);
 		break;
-
+*/
 	}
 }
 
@@ -2572,6 +2516,8 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 	SString kw2 = props->GetNewExpand("keywords3.", fileNameForExtension.c_str());
 	SendEditorString(SCI_SETKEYWORDS, 2, kw2.c_str());
 	/* For C/C++ projects, get list of typedefs for colorizing */
+	/* TODO: Either remove or port to IAnjutaSymbolManager */
+#if 0
 	if (SCLEX_CPP == lexLanguage)
 	{
 		const TMWorkspace *workspace = tm_get_workspace();
@@ -2624,6 +2570,7 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 		}
 	}
 	else
+#endif
 	{
 		SString kw1 = props->GetNewExpand("keywords2.", fileNameForExtension.c_str());
 		SendEditorString(SCI_SETKEYWORDS, 1, kw1.c_str());
@@ -2746,8 +2693,8 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 		
 		SString value_str;
 		long default_indic_type[] = {INDIC_TT, INDIC_DIAGONAL, INDIC_SQUIGGLE};
-		char *default_indic_color[] = {"0000FF", "#00FF00", "#FF0000"};
-		char *style_name[] = {"normal", "warning", "error"};
+		const char *default_indic_color[] = {"0000FF", "#00FF00", "#FF0000"};
+		const char *style_name[] = {"normal", "warning", "error"};
 		char key[200];
 		sprintf(key, "indicators.style.%s", style_name[i]);
 
@@ -2889,18 +2836,21 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 	}
 	indentSize = props->GetInt("indent.size");
 	SendEditor(SCI_SETINDENT, indentSize);
-	
+	/*
 	indentOpening = props->GetInt("indent.opening");
 	indentClosing = props->GetInt("indent.closing");
+	*/
 	indentMaintain = props->GetNewExpand("indent.maintain.", fileNameForExtension.c_str()).value();
-	
+	/*
 	SString lookback = props->GetNewExpand("statement.lookback.", fileNameForExtension.c_str());
 	statementLookback = lookback.value();
 	statementIndent = GetStyleAndWords("statement.indent.");
 	statementEnd =GetStyleAndWords("statement.end.");
 	blockStart = GetStyleAndWords("block.start.");
 	blockEnd = GetStyleAndWords("block.end.");
-
+	*/
+	
+	/*
 	SString list;
 	list = props->GetNewExpand("preprocessor.symbol.", fileNameForExtension.c_str());
 	preprocessorSymbol = list[0];
@@ -2913,7 +2863,8 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 	list = props->GetNewExpand("preprocessor.end.", fileNameForExtension.c_str());
 	preprocCondEnd.Clear();
 	preprocCondEnd.Set(list.c_str());
-
+	*/
+	
 	if (props->GetInt("vc.home.key", 1)) {
 		AssignKey(SCK_HOME, 0, SCI_VCHOME);
 		AssignKey(SCK_HOME, SCMOD_SHIFT, SCI_VCHOMEEXTEND);
@@ -3090,13 +3041,13 @@ aneditor_get(AnEditorID id)
 	AnEditor* ed;
 	if(id >= g_list_length(editors))
 	{
-		DEBUG_PRINT("Invalid AnEditorID supplied");
+		DEBUG_PRINT("%s", "Invalid AnEditorID supplied");
 		return NULL;
 	}
 	ed = (AnEditor*)g_list_nth_data(editors, (guint)id);
 	if(!ed)
 	{
-		DEBUG_PRINT("Trying to use already destroyed AnEditor Object");
+		DEBUG_PRINT("%s", "Trying to use already destroyed AnEditor Object");
 		return NULL;
 	}
 	return ed;
@@ -3108,7 +3059,7 @@ aneditor_new(gpointer propset)
   AnEditor* ed = new AnEditor((PropSetFile*)propset);
   if (!ed)
   {
-     DEBUG_PRINT("Memory allocation error.");
+     DEBUG_PRINT("%s", "Memory allocation error.");
      return ANE_ID_INVALID;
   }
   g_signal_connect(ed->GetID(), "focus_in_event", 
@@ -3132,6 +3083,13 @@ aneditor_destroy(AnEditorID id)
   /* We'll simply make it NULL to indicate that the */
   /* editor is destroyed */
   g_list_nth(editors, id)->data = NULL;
+	
+  /* Disconnect the focus in/out signals */
+  g_signal_handlers_disconnect_by_func (ed->GetID(),
+				   (void*)G_CALLBACK(on_aneditor_focus_in), ed);
+  g_signal_handlers_disconnect_by_func (ed->GetID(),
+				   (void*)G_CALLBACK(on_aneditor_focus_out), ed);
+
   delete ed;
 }
 
@@ -3172,15 +3130,17 @@ aneditor_set_parent(AnEditorID id, AnEditorID parent_id)
 	editor->SetParent(parent);
 }
 
-gint on_aneditor_focus_in(GtkWidget* widget, gpointer* unused, AnEditor* ed)
+gint
+on_aneditor_focus_in (GtkWidget* widget, gpointer* unused, AnEditor* ed)
 {
 	ed->FocusInEvent(widget);
 	return FALSE;
 }
 
-gint on_aneditor_focus_out(GtkWidget* widget, gpointer * unused, AnEditor* ed)
+gint
+on_aneditor_focus_out (GtkWidget* widget, gpointer * unused, AnEditor* ed)
 {
-	ed->EndDebugEval();
+	/* ed->EndDebugEval(); */
 	ed->FocusOutEvent(widget);
 	return FALSE;
 }
