@@ -23,7 +23,6 @@
 
 #include <gnome.h>
 #include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-plugin.h>
@@ -33,7 +32,6 @@
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
 #include <libanjuta/interfaces/ianjuta-markable.h>
-#include <libanjuta/interfaces/ianjuta-bookmark.h>
 #include <libanjuta/interfaces/ianjuta-indicable.h>
 
 #include "search-replace_backend.h"
@@ -170,8 +168,8 @@ static GladeWidget glade_widgets[] = {
 	{GE_BOOLEAN, "search.regex", NULL, NULL},
 	/* GREEDY */
 	{GE_BOOLEAN, "search.greedy", NULL, NULL},
-       	/* IGNORE_CASE */
-	{GE_BOOLEAN, "search.ignore.case", NULL, NULL},
+       	/* MATCH_CASE */
+	{GE_BOOLEAN, "search.match.case", NULL, NULL},
 	/* WHOLE_WORD */
 	{GE_BOOLEAN, "search.match.whole.word", NULL, NULL},
 	/* WORD_START */
@@ -317,7 +315,8 @@ search_and_replace (void)
 
 	if (SA_FIND_PANE == s->action)
 	{
-		gchar* name = g_strconcat(_("Find: "), s->expr.search_str, NULL);		
+		/* Avoid space in translated string */
+		gchar* name = g_strconcat(_("Find:"), " ", s->expr.search_str, NULL);		
 		AnjutaShell* shell;
 		g_object_get(G_OBJECT(sr->docman), "shell", &shell, NULL);
 		msgman = anjuta_shell_get_interface(shell, 
@@ -372,12 +371,6 @@ search_and_replace (void)
 		{		
 			fb->pos = se->start_pos;
 			offset = 0;
-/* NO - there's no reason for user to expect existing marks to be removed.
-	And that can easily be done manually by user if so desired.
-			if (s->action == SA_BOOKMARK && IANJUTA_IS_MARKABLE (fb->te))
-				ianjuta_markable_delete_all_markers(IANJUTA_MARKABLE(fb->te), 
-				                                    IANJUTA_MARKABLE_LINEMARKER, NULL);
-*/
 		//FIXME enable clearing of marks by some means other than a 0-match search
 			if (s->action == SA_HIGHLIGHT)	
 				ianjuta_indicable_clear (IANJUTA_INDICABLE(fb->te), NULL); 				
@@ -424,23 +417,13 @@ search_and_replace (void)
 					case SA_BOOKMARK:
 						if (found_line != mi->line)
 						{
-							found_line = mi->line;
-						
-							if (fb->te == NULL)
-								fb->te =
-									IANJUTA_EDITOR (ianjuta_document_manager_get_current_document
-										(sr->docman, NULL));
-
-							if (IANJUTA_IS_MARKABLE (fb->te) &&
-								!ianjuta_markable_is_marker_set (
-														IANJUTA_MARKABLE(fb->te),
-														mi->line,
-														IANJUTA_MARKABLE_BOOKMARK,
-														NULL))
-							{
-								ianjuta_bookmark_toggle (IANJUTA_BOOKMARK(fb->te),
-														mi->line, FALSE, NULL);
-							}
+							GFile* file = g_file_new_for_uri (fb->uri);
+							found_line = mi->line + 1; /* different line count between search and editor */
+							ianjuta_document_manager_add_bookmark (sr->docman,
+																   file,
+																   found_line,
+																   NULL);
+							g_object_unref (file);			  
 						}
 						break;
 						
@@ -644,26 +627,13 @@ static void
 write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se,
 				   MatchInfo *mi)
 {
-	gchar *match_line;
+	gchar *match_line = file_match_line_from_pos(fb, mi->pos);
+	int line = mi->line;
 	char buf[BUFSIZ];
-	gchar *tmp;
 	
-	match_line = file_match_line_from_pos(fb, mi->pos);
-
-	if (SE_BUFFER == se->type)
-	{
-		/* DEBUG_PRINT ("FBPATH  %s\n", fb->path); */
-		const gchar* filename = ianjuta_document_get_filename(IANJUTA_DOCUMENT(se->te), NULL);
-		tmp = g_strrstr(fb->path, "/");
-		tmp = g_strndup(fb->path, tmp + 1 -(fb->path));
-		snprintf(buf, BUFSIZ, "%s%s:%d:%s\n", tmp, filename,
-		         mi->line, match_line);
-		g_free(tmp);
-	}
-	else /* if (SE_FILE == se->type) */
-	{
-		snprintf(buf, BUFSIZ, "%s:%d:%s\n", se->path, mi->line + 1, match_line);
-	}
+	if (se->type == SE_FILE)
+		++line;
+    snprintf(buf, BUFSIZ, "%s:%d:%s\n", fb->path, line, match_line);
 	g_free(match_line);
 	ianjuta_message_view_buffer_append (view, buf, NULL);
 }
@@ -711,13 +681,39 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 static void
 save_not_opened_files(FileBuffer *fb)
 {
-	FILE *fp;
+	GFile *file;
+	GOutputStream *os;
+	gsize written;
+	gsize size;
+	gchar *buffer;
 
-	fp = fopen(fb->path, "wb");	
-	if (!fp)
-			return;
-	fwrite(fb->buf, fb->len, 1, fp);
-	fclose(fp);
+	file = g_file_new_for_uri (fb->uri);
+	os = G_OUTPUT_STREAM (g_file_replace (file, 
+			NULL,
+			FALSE,
+			G_FILE_CREATE_NONE,
+			NULL,
+			NULL));
+	if (os == NULL)
+	{
+		g_object_unref (file);
+		return;
+	}
+
+	buffer = fb->buf;
+	size = fb->len;
+	do
+	{
+		written = g_output_stream_write (os, 
+				buffer, size, NULL, NULL);
+		
+		size -= written;
+		buffer += size;
+	}
+	while (written != -1 && size > 0);
+	g_output_stream_close(os, NULL, NULL);
+	g_object_unref (os);
+	g_object_unref (file);
 }
 
 static gboolean
@@ -776,7 +772,7 @@ search_replace_next_previous(SearchDirection dir)
 	}	
 	else
 	{
-		DEBUG_PRINT ("sr null\n");
+		DEBUG_PRINT ("%s", "sr null\n");
 	}
 }
 
@@ -1172,7 +1168,7 @@ search_replace_populate(void)
 	populate_value(SEARCH_STRING, &(sr->search.expr.search_str));
 	populate_value(SEARCH_REGEX, &(sr->search.expr.regex));
 	populate_value(GREEDY, &(sr->search.expr.greedy));
-	populate_value(IGNORE_CASE, &(sr->search.expr.ignore_case));
+	populate_value(MATCH_CASE, &(sr->search.expr.match_case));
 	populate_value(WHOLE_WORD, &(sr->search.expr.whole_word));
 	populate_value(WHOLE_LINE, &(sr->search.expr.whole_line));
 	populate_value(WORD_START, &(sr->search.expr.word_start));
@@ -1433,8 +1429,8 @@ search_update_dialog(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.regex);
 	widget = sr_get_gladewidget(GREEDY)->widget;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.greedy);
-	widget = sr_get_gladewidget(IGNORE_CASE)->widget;
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.ignore_case);
+	widget = sr_get_gladewidget(MATCH_CASE)->widget;
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.match_case);
 	widget = sr_get_gladewidget(WHOLE_WORD)->widget;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), s->expr.whole_word);
 	widget = sr_get_gladewidget(WHOLE_LINE)->widget;
@@ -1816,7 +1812,7 @@ void search_replace_find_usage(const gchar *symbol)
 	sr->search.expr.search_str = g_strdup (symbol);
 	sr->search.expr.regex = FALSE;
 	sr->search.expr.greedy = FALSE;
-	sr->search.expr.ignore_case = FALSE;
+	sr->search.expr.match_case = TRUE;
 	sr->search.expr.whole_word = TRUE;
 	sr->search.expr.whole_line = FALSE;
 	sr->search.expr.word_start = FALSE;
