@@ -27,17 +27,15 @@
 #include <ctype.h>
 #include <sys/wait.h>
 
-#include <gnome.h>
-#include <gtk/gtkwidget.h>
-#include <glade/glade.h>
+#include <glade/glade-xml.h>
+#include <gtk/gtk.h>
 
 #include <gdl/gdl-dock.h>
 #include <gdl/gdl-dock-bar.h>
 #include <gdl/gdl-switcher.h>
 
-#include <bonobo/bonobo-dock-item.h>
-
 #include <libanjuta/anjuta-shell.h>
+#include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-plugin-manager.h>
@@ -51,11 +49,6 @@
 #define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta.glade"
 #define ICON_FILE "anjuta-preferences-general-48.png"
 
-#define DOCK_PH_LEFT    "ph_left"
-#define DOCK_PH_RIGHT   "ph_right"
-#define DOCK_PH_TOP     "ph_top"
-#define DOCK_PH_BOTTOM  "ph_bottom"
-
 static void anjuta_app_layout_load (AnjutaApp *app,
 									const gchar *layout_filename,
 									const gchar *name);
@@ -64,7 +57,43 @@ static void anjuta_app_layout_save (AnjutaApp *app,
 									const gchar *name);
 
 static gpointer parent_class = NULL;
-static GList* toolbars = NULL;
+static GtkToolbarStyle style = -1;
+
+static void
+on_toolbar_style_changed (GConfClient* client, guint id, GConfEntry* entry,
+						  gpointer user_data)
+{
+	AnjutaApp* app = ANJUTA_APP (user_data);
+	
+	char* tb_style = anjuta_preferences_get (app->preferences, "anjuta.toolbar.style");
+	
+	if (tb_style)
+	{	
+		if (strcasecmp (tb_style, "Default") == 0)
+			style = -1;
+		else if (strcasecmp (tb_style, "Both") == 0)
+			style = GTK_TOOLBAR_BOTH;
+		else if (strcasecmp (tb_style, "Horiz") == 0)
+			style = GTK_TOOLBAR_BOTH_HORIZ;
+		else if (strcasecmp (tb_style, "Icons") == 0)
+			style = GTK_TOOLBAR_ICONS;
+		else if (strcasecmp (tb_style, "Text") == 0)
+			style = GTK_TOOLBAR_TEXT;
+		
+		DEBUG_PRINT ("Toolbar style: %s", tb_style);
+		
+		g_free(tb_style);
+	}
+	
+	if (style != -1)
+	{
+		gtk_toolbar_set_style (GTK_TOOLBAR (app->toolbar), style);
+	}
+	else
+	{
+		gtk_toolbar_unset_style (GTK_TOOLBAR (app->toolbar));
+	}
+}
 
 static void
 on_gdl_style_changed (GConfClient* client, guint id, GConfEntry* entry,
@@ -93,7 +122,7 @@ on_gdl_style_changed (GConfClient* client, guint id, GConfEntry* entry,
 		g_free (pr_style);
 	}
 	g_object_set (G_OBJECT(app->layout_manager->master), "switcher-style",
-					  style, NULL);
+				  style, NULL);
 }
 
 static void
@@ -146,9 +175,8 @@ on_layout_dirty_notify (GObject *object, GParamSpec *pspec, gpointer user_data)
 }
 
 static void
-on_layout_locked_notify (GdlDockMaster *master,
-                         GParamSpec    *pspec,
-                         AnjutaApp     *app)
+on_layout_locked_notify (GdlDockMaster *master, GParamSpec *pspec,
+						 AnjutaApp     *app)
 {
 	AnjutaUI *ui;
 	GtkAction *action;
@@ -163,213 +191,16 @@ on_layout_locked_notify (GdlDockMaster *master,
 								  (locked == 1));
 }
 
-static void
-on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
-{
-	AnjutaApp *app;
-	BonoboDockItem *dock_item;
-	const gchar *name;
-	gint band;
-	gint position;
-	gint offset;
-
-	
-	name = gtk_widget_get_name (widget);
-	app = g_object_get_data (G_OBJECT(widget), "app");
-	dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");
-	band = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "band"));
-	position = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "position"));
-	offset = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "offset"));
-
-	
-	if (gtk_check_menu_item_get_active (menuitem))
-	{
-		if (!dock_item)
-		{
-			static gint count;
-			gchar *unique_name = g_strdup_printf ("%s-%d", name, count);
-			
-			/* gnome_app_add_docked() does not allow adding a widget using
-			 * a previously used name (even if the previous widget has
-			 * has be destroyed. Hence a unique_name is used by using a 
-			 * static counter */
-			DEBUG_PRINT ("Adding dock item %s band %d, offset %d, position %d", unique_name,
-						 band, offset, position);
-			
-			/* Widget not yet added to the dock. Add it */
-			gnome_app_add_docked (GNOME_APP (app), widget,
-								  unique_name,
-								  BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL |
-								  BONOBO_DOCK_ITEM_BEH_NEVER_FLOATING,
-								  BONOBO_DOCK_TOP, band, position, offset);
-									   									   
-			dock_item = gnome_app_get_dock_item_by_name (GNOME_APP (app),
-														 unique_name);
-			g_object_set_data_full (G_OBJECT(dock_item), "unique_name", unique_name, g_free);
-			g_object_set_data (G_OBJECT(widget), "dock_item", dock_item);
-			count++;
-		}
-		gtk_widget_show (GTK_WIDGET (dock_item));
-		gtk_widget_show (GTK_BIN (dock_item)->child);
-	}
-	else if (dock_item)
-	{
-		gtk_widget_hide (GTK_WIDGET (dock_item));
-		gtk_widget_hide (GTK_BIN (dock_item)->child);
-	}
-}
-
-static void
-on_merge_widget_destroy (GtkWidget *merge_widget, GtkWidget *menuitem)
-{
-	toolbars = g_list_remove (toolbars, merge_widget);
-	DEBUG_PRINT ("Destroying menuitem for toolbar widget");
-	gtk_widget_destroy (menuitem);
-}
-
-static void
-on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
-					 GtkWidget *ui_container)
-{
-	DEBUG_PRINT ("Adding UI item ...");
-	
-	if (GTK_IS_MENU_BAR (widget))
-	{
-		gnome_app_set_menus (GNOME_APP (ui_container), GTK_MENU_BAR (widget));
-		gtk_widget_show (widget);
-	}
-	else
-	{
-		static gint count = 0;
-		const gchar *toolbarname;
-		gchar* visible_key;
-		gchar* band_key;
-		gchar* position_key;
-		gchar* offset_key;		
-		AnjutaPreferences *pr;
-		GtkWidget *menuitem;
-		gint band;
-		gint position;
-		gint offset;
-		pr = ANJUTA_PREFERENCES (ANJUTA_APP(ui_container)->preferences);
-		
-		/* Showing the arrows seem to break anything completly! */
-		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (widget), FALSE);
-		
-		gtk_widget_show (widget);
-		g_object_set_data (G_OBJECT (widget), "app", ui_container);
-		
-		/* Load toolbar position */
-		toolbarname = gtk_widget_get_name (widget);
-		band_key = g_strconcat (toolbarname, ".band", NULL);
-		position_key = g_strconcat (toolbarname, ".position", NULL);
-		offset_key = g_strconcat (toolbarname, ".offset", NULL);		
-		band = anjuta_preferences_get_int_with_default(pr, band_key, -1);
-		position = anjuta_preferences_get_int_with_default(pr, position_key, 0);
-		offset = anjuta_preferences_get_int_with_default(pr, offset_key, 0);		
-		/* Without these check you might see odd results */
-		if (band < 1)
-			band = count + 1;
-		g_object_set_data(G_OBJECT(widget), "position", GINT_TO_POINTER(position));
-		g_object_set_data(G_OBJECT(widget), "offset", GINT_TO_POINTER(offset));
-		g_object_set_data (G_OBJECT (widget), "band",
-						   GINT_TO_POINTER(band));
-		g_free(offset_key);
-		g_free(position_key);
-		g_free(band_key);
-		DEBUG_PRINT ("Adding toolbar: %s", toolbarname);
-		
-		if (!ANJUTA_APP (ui_container)->toolbars_menu)
-		{
-			ANJUTA_APP (ui_container)->toolbars_menu = gtk_menu_new ();
-			gtk_widget_show (GTK_WIDGET (ANJUTA_APP (ui_container)->toolbars_menu));
-		}
-		
-		menuitem = gtk_check_menu_item_new_with_label (toolbarname);
-		gtk_menu_append (GTK_MENU (ANJUTA_APP (ui_container)->toolbars_menu),
-						 menuitem);
-		gtk_widget_show (GTK_WIDGET (menuitem));
-		g_signal_connect (G_OBJECT (menuitem), "toggled",
-						  G_CALLBACK (on_toolbar_view_toggled), widget);
-		g_object_set_data(G_OBJECT(widget), "menuitem", menuitem);
-		
-		/* When the toolbar is destroyed make sure corresponding menuitem is
-		 * also destroyed */
-		g_signal_connect (widget, "destroy",
-						  G_CALLBACK (on_merge_widget_destroy),
-						  menuitem);
-		
-		toolbars = g_list_append(toolbars, widget);
-
-		/* Show/hide toolbar */
-		visible_key = g_strconcat (toolbarname, ".visible", NULL);
-		if (anjuta_preferences_get_int_with_default (pr, visible_key,
-													 (count == 0)? 1:0))
-		{
-			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
-											TRUE);
-		}
-		g_free (visible_key);
-		count ++;
-	}
-}
-
 static void
 on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 				 AnjutaSession *session, AnjutaApp *app)
 {
 	gchar *geometry, *layout_file;
 	GdkWindowState state;
-	GList* node = toolbars;
-	
 	
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 	
-	/* Save toolbars */
-	while (node)
-	{
-		GtkWidget* widget = node->data;
-		GtkWidget* dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");;
-		const gchar* toolbarname = gtk_widget_get_name(widget);
-		AnjutaPreferences* pr = ANJUTA_PREFERENCES (app->preferences);
-				
-		if (dock_item)
-		{
-			gboolean visible;
-			gchar* key = g_strconcat (toolbarname, ".visible", NULL);
-			gchar* band_key = g_strconcat (toolbarname, ".band", NULL);
-			gchar* position_key = g_strconcat (toolbarname, ".position", NULL);
-			gchar* offset_key = g_strconcat (toolbarname, ".offset", NULL);
-			GnomeApp* gnome_app = GNOME_APP(app);
-			
-			/* Save visibility */
-			g_object_get(G_OBJECT(dock_item), "visible", &visible, NULL);
-			anjuta_preferences_set_int(pr, key, visible);
-			g_free(key);
-			
-			/* Save toolbar position */
-			if (gnome_app->dock != NULL)
-			{
-				guint band;
-				guint position;
-				guint offset;
-				BonoboDockPlacement placement;
-				gchar* unique_name = g_object_get_data(G_OBJECT(dock_item), "unique_name");
-				
-				BonoboDockItem* item = bonobo_dock_get_item_by_name(BONOBO_DOCK(gnome_app->dock), 
-																  unique_name, &placement, 
-																   &band, &position, &offset);
-				g_return_if_fail(item != NULL);
-			
-				anjuta_preferences_set_int(pr, band_key, band);
-				anjuta_preferences_set_int(pr, position_key, position);
-				anjuta_preferences_set_int(pr, offset_key, offset);
-			}
-		}
-		node = g_list_next(node);
-	}
-	
 	/* Save geometry */
 	state = gdk_window_get_state (GTK_WIDGET (app)->window);
 	if (state & GDK_WINDOW_STATE_MAXIMIZED) {
@@ -437,18 +268,10 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 	}
 }
 
-static void
-on_accel_changed (GtkAccelGroup *accelgroup, guint arg1, GdkModifierType arg2,
-				  GClosure *arg3, AnjutaApp *app)
-{
-	gnome_accelerators_sync ();
-}
-
 static void
 anjuta_app_dispose (GObject *widget)
 {
 	AnjutaApp *app;
-	GList *tmp_list;
 	
 	g_return_if_fail (ANJUTA_IS_APP (widget));
 	
@@ -482,18 +305,6 @@ anjuta_app_dispose (GObject *widget)
 		app->values = NULL;
 	}
 	
-	/* We need to destroy to the toolbars now so that the
-	 * on_merge_widget_destroy() does not produce a error trying to destory
-	 * already destroyed menuitems which happen when the window is being
-	 * destroyed
-	 *
-	 * Make a tmp list because the handler removes items from 'toolbars' list.
-	 * FIXME: Why is 'toolbars' a global static variable?
-	 */
-	tmp_list = g_list_copy (toolbars);
-	g_list_foreach (tmp_list, (GFunc)gtk_widget_destroy, NULL);
-	g_list_free (tmp_list);
-	
 	if (app->layout_manager) {
 		g_object_unref (app->layout_manager);
 		app->layout_manager = NULL;
@@ -510,7 +321,8 @@ anjuta_app_dispose (GObject *widget)
 		g_object_unref (G_OBJECT (app->status));
 		app->status = NULL;
 	}
-	GNOME_CALL_PARENT(G_OBJECT_CLASS, dispose, (widget));
+
+	G_OBJECT_CLASS (parent_class)->dispose (widget);
 }
 
 static void
@@ -525,40 +337,51 @@ anjuta_app_finalize (GObject *widget)
 	gtk_widget_destroy (GTK_WIDGET (app->ui));
 	gtk_widget_destroy (GTK_WIDGET (app->preferences));
 	
-	GNOME_CALL_PARENT(G_OBJECT_CLASS, finalize, (widget));
+	G_OBJECT_CLASS (parent_class)->finalize (widget);
 }
 
 static void
 anjuta_app_instance_init (AnjutaApp *app)
 {
 	gint merge_id;
-	GtkWidget *toolbar_menu, *about_menu;
+	GtkWidget *menubar, *about_menu;
 	GtkWidget *view_menu, *hbox;
+	GtkWidget *main_box;
 	GtkWidget *dockbar;
-	GtkAccelGroup *accel_group;
 	GtkAction* action;
 	GList *plugins_dirs = NULL;
 	GdkGeometry size_hints = {
     	100, 100, 0, 0, 100, 100, 1, 1, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST
   	};
 	
-	DEBUG_PRINT ("Initializing Anjuta...");
+	DEBUG_PRINT ("%s", "Initializing Anjuta...");
 	
 	gtk_window_set_geometry_hints (GTK_WINDOW (app), GTK_WIDGET (app),
 								   &size_hints, GDK_HINT_RESIZE_INC);
 	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 	
-	gnome_app_enable_layout_config (GNOME_APP (app), FALSE);
-	
-	app->layout_manager = NULL;
+	/*
+	 * Main box
+	 */
+	main_box = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (app), main_box);
+	gtk_widget_show (main_box);
 	
 	app->values = NULL;
 	app->widgets = NULL;
-
+	
+	/* Status bar */
+	app->status = ANJUTA_STATUS (anjuta_status_new ());
+	anjuta_status_set_title_window (app->status, GTK_WIDGET (app));
+	gtk_widget_show (GTK_WIDGET (app->status));
+	gtk_box_pack_end (GTK_BOX (main_box),
+					  GTK_WIDGET (app->status), FALSE, TRUE, 0);
+	g_object_ref (G_OBJECT (app->status));
+	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer)&app->status);
+	
 	/* configure dock */
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
-	gnome_app_set_contents (GNOME_APP (app), hbox);
 	app->dock = gdl_dock_new ();
 	gtk_widget_show (app->dock);
 	gtk_box_pack_end(GTK_BOX (hbox), app->dock, TRUE, TRUE, 0);
@@ -572,25 +395,9 @@ anjuta_app_instance_init (AnjutaApp *app)
 					  G_CALLBACK (on_layout_dirty_notify), app);
 	g_signal_connect (app->layout_manager->master, "notify::locked",
 					  G_CALLBACK (on_layout_locked_notify), app);
-	/* Status bar */
-	app->status = ANJUTA_STATUS (anjuta_status_new ());
-	anjuta_status_set_title_window (app->status, GTK_WIDGET (app));
-	gtk_widget_show (GTK_WIDGET (app->status));
-	gnome_app_set_statusbar (GNOME_APP (app), GTK_WIDGET (app->status));
-	g_object_ref (G_OBJECT (app->status));
-	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer)&app->status);
 	
 	/* UI engine */
 	app->ui = anjuta_ui_new ();
-	
-	accel_group = anjuta_ui_get_accel_group (app->ui);
-	g_signal_connect (accel_group, "accel-changed",
-					  G_CALLBACK (on_accel_changed), app);
-	
-	gtk_window_add_accel_group (GTK_WINDOW (app), accel_group);
-	g_signal_connect (G_OBJECT (app->ui),
-					  "add_widget", G_CALLBACK (on_add_merge_widget),
-					  app);
 	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer)&app->ui);
 	
 	/* Plugin Manager */
@@ -636,28 +443,42 @@ anjuta_app_instance_init (AnjutaApp *app)
 
 	/* Merge UI */
 	merge_id = anjuta_ui_merge (app->ui, UI_FILE);
+	
+	/* Adding accels group */
+	gtk_window_add_accel_group (GTK_WINDOW (app), 
+								gtk_ui_manager_get_accel_group (GTK_UI_MANAGER (app->ui)));
+	
+	/* create main menu */
+	menubar = gtk_ui_manager_get_widget (GTK_UI_MANAGER (app->ui),
+										 "/MenuMain");
+	gtk_box_pack_start (GTK_BOX (main_box), menubar, FALSE, FALSE, 0);
+	gtk_widget_show (menubar);
+	
+	/* create toolbar */	
+	app->toolbar = gtk_ui_manager_get_widget (GTK_UI_MANAGER (app->ui),
+										 "/ToolbarMain");
+	gtk_box_pack_start (GTK_BOX (main_box), app->toolbar, FALSE, FALSE, 0);
+	action = gtk_ui_manager_get_action (GTK_UI_MANAGER (app->ui),
+										"/MenuMain/MenuView/Toolbar");
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION(action),
+								  anjuta_preferences_get_int_with_default (app->preferences,
+																		   "anjuta.toolbar.visible",
+																		   TRUE));
+	anjuta_preferences_notify_add (app->preferences, "anjuta.toolbar.style",
+								   on_toolbar_style_changed, app, NULL);
+	on_toolbar_style_changed (NULL, 0, NULL, app);
+
+	/* Create widgets menu */
+	view_menu = 
+		gtk_ui_manager_get_widget (GTK_UI_MANAGER(app->ui),
+								  "/MenuMain/MenuView");
+	app->view_menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (view_menu));	
 
 	/* Disable unavailible tutorials */
 	action = anjuta_ui_get_action(app->ui, "ActionGroupHelp", "ActionHelpTutorial");
 	g_object_set(G_OBJECT(action), "visible", FALSE, NULL);
 	action = anjuta_ui_get_action(app->ui, "ActionGroupHelp", "ActionHelpAdvancedTutorial");
 	g_object_set(G_OBJECT(action), "visible", FALSE, NULL);
-
-	/* create toolbar menus */
-	toolbar_menu =
-		gtk_ui_manager_get_widget (GTK_UI_MANAGER(app->ui),
-								  "/MenuMain/MenuView/Toolbars");
-	if (toolbar_menu)
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (toolbar_menu),
-								   app->toolbars_menu);
-	else
-		g_warning ("Cannot retrive main menu widget");
-
-	/* Create widgets menu */
-	view_menu = 
-		gtk_ui_manager_get_widget (GTK_UI_MANAGER(app->ui),
-								  "/MenuMain/MenuView");
-	app->view_menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (view_menu));
 	
 	/* Create about plugins menu */
 	about_menu = 
@@ -665,12 +486,18 @@ anjuta_app_instance_init (AnjutaApp *app)
 								   "/MenuMain/PlaceHolderHelpMenus/MenuHelp/"
 								   "PlaceHolderHelpAbout/AboutPlugins");
 	about_create_plugins_submenu (ANJUTA_SHELL (app), about_menu);
-							
+	
+	/* Add main view */
+	gtk_box_pack_start (GTK_BOX (main_box), hbox, TRUE, TRUE, 0);
+						
 	/* Connect to session */
 	g_signal_connect (G_OBJECT (app), "save_session",
 					  G_CALLBACK (on_session_save), app);
 	g_signal_connect (G_OBJECT (app), "load_session",
 					  G_CALLBACK (on_session_load), app);
+	
+	/* Loading accels */
+	anjuta_ui_load_accels ();
 }
 
 static void
@@ -772,6 +599,9 @@ anjuta_app_layout_save (AnjutaApp *app, const gchar *filename,
 	gdl_dock_layout_save_layout (app->layout_manager, name);
 	if (!gdl_dock_layout_save_to_file (app->layout_manager, filename))
 		g_warning ("Saving dock layout to '%s' failed!", filename);
+		
+	/* This is a good place to save the accels too */
+	anjuta_ui_save_accels ();
 }
 
 static void
@@ -949,7 +779,7 @@ remove_from_widgets_hash (gpointer name, gpointer hash_widget, gpointer widget)
 static void
 on_widget_destroy (GtkWidget *widget, AnjutaApp *app)
 {
-	DEBUG_PRINT ("Widget about to be destroyed");
+	DEBUG_PRINT ("%s", "Widget about to be destroyed");
 	g_hash_table_foreach_remove (app->widgets, remove_from_widgets_hash,
 								 widget);
 }
@@ -958,20 +788,6 @@ static void
 on_widget_remove (GtkWidget *container, GtkWidget *widget, AnjutaApp *app)
 {
 	GtkWidget *dock_item;
-	GList* node = toolbars;
-	while (node)
-	{
-		if (node->data == widget)
-		{
-			g_message("Removing toolbar");
-			GtkWidget* menuitem = GTK_WIDGET(g_object_get_data(G_OBJECT(widget), "menuitem"));
-			gtk_widget_hide(menuitem);
-			gtk_widget_destroy(menuitem);
-			toolbars = g_list_delete_link(toolbars, node);
-			break;
-		}
-		node = g_list_next(node);
-	}
 
 	dock_item = g_object_get_data (G_OBJECT (widget), "dockitem");
 	if (dock_item)
@@ -985,7 +801,7 @@ on_widget_remove (GtkWidget *container, GtkWidget *widget, AnjutaApp *app)
 	if (g_hash_table_foreach_remove (app->widgets,
 									 remove_from_widgets_hash,
 									 widget)){
-		DEBUG_PRINT ("Widget removed from container");
+		DEBUG_PRINT ("%s", "Widget removed from container");
 	}
 }
 
@@ -996,7 +812,7 @@ on_widget_removed_from_hash (gpointer widget)
 	GtkWidget *menuitem;
 	GdlDockItem *dockitem;
 	
-	DEBUG_PRINT ("Removing widget from hash");
+	DEBUG_PRINT ("%s", "Removing widget from hash");
 	
 	app = g_object_get_data (G_OBJECT (widget), "app-object");
 	dockitem = g_object_get_data (G_OBJECT (widget), "dockitem");
@@ -1223,6 +1039,6 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_profile_manager = anjuta_app_get_profile_manager;
 }
 
-ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GNOME_TYPE_APP);
+ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GTK_TYPE_WINDOW);
 ANJUTA_TYPE_ADD_INTERFACE(anjuta_shell, ANJUTA_TYPE_SHELL);
 ANJUTA_TYPE_END;
