@@ -29,8 +29,7 @@
 #include <sys/stat.h>
 
 #include <libgnome/gnome-program.h>
-#include <gtk/gtkwindow.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gtk/gtk.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
@@ -118,8 +117,9 @@ get_real_path (const gchar *file_name)
 	{
 		gchar path[PATH_MAX+1];
 		gchar *uri_scheme;
+		GFile *file = g_file_new_for_commandline_arg (file_name);
 		
-		uri_scheme = gnome_vfs_get_uri_scheme (file_name);
+		uri_scheme = g_file_get_uri_scheme (file);
 		if (!uri_scheme)
 		{
 			memset(path, '\0', PATH_MAX+1);
@@ -127,6 +127,7 @@ get_real_path (const gchar *file_name)
 			return g_strdup (path);
 		}
 		g_free (uri_scheme);
+		g_object_unref (file);
 		return g_strdup (file_name);
 	}
 	else
@@ -344,7 +345,10 @@ main (int argc, char *argv[])
 								  GNOME_PARAM_APP_DATADIR, data_dir,
 								  GNOME_PARAM_NONE);
 	g_free (data_dir);
-	
+
+	/* Init debug helpers */
+	anjuta_debug_init ();
+
 	/* Get the command line files */
 	get_command_line_args ();
 	
@@ -355,7 +359,7 @@ main (int argc, char *argv[])
 		if (!bacon_message_connection_get_is_server (connection) &&
 			 no_client == FALSE) 
 		{
-			DEBUG_PRINT("Client");
+			DEBUG_PRINT("%s", "Client");
 			send_bacon_message ();
 
 			/* we never popup a window... tell startup-notification
@@ -369,7 +373,7 @@ main (int argc, char *argv[])
 		}
 		else 
 		{
-			DEBUG_PRINT("Server");
+			DEBUG_PRINT("%s", "Server");
 			bacon_message_connection_set_callback (connection,
 							       on_message_received,
 							       NULL);
@@ -384,7 +388,7 @@ main (int argc, char *argv[])
 
 	im_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_SPLASH_SCREEN);
 	
-	/* Initialize applicatoin */
+	/* Initialize application */
 	app = anjuta_new (argv[0], file_list, no_splash, no_session, no_files,
 					  im_file, proper_shutdown, anjuta_geometry);
 	
@@ -396,7 +400,5 @@ main (int argc, char *argv[])
 	gtk_widget_show (GTK_WIDGET (app));
 	gtk_main();
 	
-	gnome_vfs_shutdown();
-	
 	return 0;
 }
